tweak_moodle_heading: Hide H2 heading for Moodle LMS
Description
You may want the title of the article to be different from the title of the
resource. Call this function in a code chunk somewhere in your R Markdown file.
Usage
tweak_moodle_heading()
Arguments
Value
Script block that makes H2 head of the content invisible.